@@ -22,7 +22,7 @@
 #include "mozilla/Logging.h"
 #include "mozilla/StaticPrefs_widget.h"
 #include "mozilla/StaticPtr.h"
-#include "nsBaseWidget.h"
+#include "nsIWidget.h"
 #include "nsWindow.h"
 #include "transport/runnable_utils.h"
 #include "WinEventObserver.h"
@@ -439,7 +439,7 @@ bool WinWindowOcclusionTracker::IsInWinWindowOcclusionThread() {
          sTracker->mThread->thread_id() == PlatformThread::CurrentId();
 }
 
-void WinWindowOcclusionTracker::Enable(nsBaseWidget* aWindow, HWND aHwnd) {
+void WinWindowOcclusionTracker::Enable(nsIWidget* aWindow, HWND aHwnd) {
   MOZ_ASSERT(NS_IsMainThread());
   LOG(LogLevel::Info, "WinWindowOcclusionTracker::Enable() aWindow %p aHwnd %p",
       aWindow, aHwnd);
@@ -459,7 +459,7 @@ void WinWindowOcclusionTracker::Enable(nsBaseWidget* aWindow, HWND aHwnd) {
   mSerializedTaskDispatcher->PostTaskToCalculator(runnable.forget());
 }
 
-void WinWindowOcclusionTracker::Disable(nsBaseWidget* aWindow, HWND aHwnd) {
+void WinWindowOcclusionTracker::Disable(nsIWidget* aWindow, HWND aHwnd) {
   MOZ_ASSERT(NS_IsMainThread());
   LOG(LogLevel::Info,
       "WinWindowOcclusionTracker::Disable() aWindow %p aHwnd %p", aWindow,
@@ -479,7 +479,7 @@ void WinWindowOcclusionTracker::Disable(nsBaseWidget* aWindow, HWND aHwnd) {
   mSerializedTaskDispatcher->PostTaskToCalculator(runnable.forget());
 }
 
-void WinWindowOcclusionTracker::OnWindowVisibilityChanged(nsBaseWidget* aWindow,
+void WinWindowOcclusionTracker::OnWindowVisibilityChanged(nsIWidget* aWindow,
                                                           bool aVisible) {
   MOZ_ASSERT(NS_IsMainThread());
   LOG(LogLevel::Info,
@@ -695,7 +695,7 @@ void WinWindowOcclusionTracker::UpdateOcclusionState(
     if (!widget) {
       continue;
     }
-    auto* baseWidget = static_cast<nsBaseWidget*>(widget.get());
+    auto* baseWidget = static_cast<nsIWidget*>(widget.get());
     baseWidget->NotifyOcclusionState(occlState);
     if (baseWidget->SizeMode() != nsSizeMode_Minimized) {
       mNumVisibleRootWindows++;
@@ -769,7 +769,7 @@ void WinWindowOcclusionTracker::MarkNonIconicWindowsOccluded() {
     if (!widget) {
       continue;
     }
-    auto* baseWidget = static_cast<nsBaseWidget*>(widget.get());
+    auto* baseWidget = static_cast<nsIWidget*>(widget.get());
     auto state = (baseWidget->SizeMode() == nsSizeMode_Minimized)
                      ? OcclusionState::HIDDEN
                      : OcclusionState::OCCLUDED;
